@@ -2,7 +2,7 @@
  * UIDevice+VLC.h
  * VLC for iOS
  *****************************************************************************
- * Copyright (c) 2013-2015 VideoLAN. All rights reserved.
+ * Copyright (c) 2013-2017 VideoLAN. All rights reserved.
  * $Id$
  *
  * Authors: Felix Paul Kühne <fkuehne # videolan.org>
@@ -14,8 +14,7 @@
 
 @interface UIDevice (VLC)
 
-@property (readonly) int VLCSpeedCategory;
 @property (readonly) NSNumber *VLCFreeDiskSpace;
 @property (readonly) BOOL VLCHasExternalDisplay;
-
+@property (readonly) BOOL isiPhoneX;
 @end
